==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/Save/ts/Save_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+77"/>
        <source>Overwrite File?</source>
        <translation>¿Sobrescribir archivo?</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; already exists. Do you wish to overwrite it?</source>
        <translation type="obsolete">El archivo &quot;%1&quot; ya existe. ¿Desea sobreescribirlo?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translation>El archivo &apos;%1&apos; ya existe. ¿Desea sobreescribirlo?</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Todos los colores personalizados se &apos;redondea&apos; con una precisión de color fijo.</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>File Format Version Not Recommended</source>
        <translation>Versión del archivo formato no se recomienda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translation>La versión del formato del archivo que está utilizando no se recomienda: &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translation>Todas las entidades y las capas negras se guardará como blanco.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Proceed?</source>
        <translation>¿Desea continuar?</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Saved drawing:</source>
        <translation>Dibujo guardado:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color. Proceed?</source>
        <translation type="obsolete">Todos los colores personalizados se &apos;redondea&apos; con una precisión de color fijo. ¿Desea continuar?</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Saving...</source>
        <translation>Ahorro...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translation>Guardarlas en un archivo formato de la versión &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translation>Entidades y capas negras se guardan como blanco.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Los colores personalizados se &apos;redondea&apos; con una precisión de color fijo.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>File %1 has not been saved.</source>
        <translation>Archivo %1 no se ha guardado.</translation>
    </message>
    <message>
        <source>Saved drawing: %1</source>
        <translation type="obsolete">Dibujo guardado: %1</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/Save/ts/Save_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+78"/>
        <source>Overwrite File?</source>
        <translation>¿Sobrescribir archivo?</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; already exists. Do you wish to overwrite it?</source>
        <translation type="obsolete">El archivo &quot;%1&quot; ya existe. ¿Desea sobreescribirlo?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translation>El archivo &apos;%1&apos; ya existe. ¿Desea sobreescribirlo?</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Todos los colores personalizados se &apos;redondea&apos; con una precisión de color fijo.</translation>
    </message>
    <message>
        <location line="-4"/>
        <source>File Format Version Not Recommended</source>
        <translation>Versión del archivo formato no se recomienda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translation>La versión del formato del archivo que está utilizando no se recomienda: &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom properties will not be saved.</source>
        <translation>Las propiedades personalizadas no se guardarán.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translation>Todas las entidades y las capas negras se guardará como blanco.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Proceed?</source>
        <translation>¿Desea continuar?</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Saved drawing:</source>
        <translation>Dibujo guardado:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color. Proceed?</source>
        <translation type="obsolete">Todos los colores personalizados se &apos;redondea&apos; con una precisión de color fijo. ¿Desea continuar?</translation>
    </message>
    <message>
        <location line="-32"/>
        <source>Saving...</source>
        <translation>Ahorro...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translation>Guardarlas en un archivo formato de la versión &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translation>Entidades y capas negras se guardan como blanco.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Los colores personalizados se &apos;redondea&apos; con una precisión de color fijo.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>File %1 has not been saved.</source>
        <translation>Archivo %1 no se ha guardado.</translation>
    </message>
    <message>
        <source>Saved drawing: %1</source>
        <translation type="obsolete">Dibujo guardado: %1</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
</context>
</TS>
